@@ -18,7 +18,6 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
-#include "ReviewsModel.h"
 #include <ReviewsBackend/AbstractReviewsBackend.h>
 #include <ReviewsBackend/Review.h>
 #include <resources/ResourcesModel.h>
@@ -34,10 +33,7 @@ ReviewsModel::ReviewsModel(QObject* parent)
     , m_canFetchMore(true)
 {}
 
-ReviewsModel::~ReviewsModel()
-{
-    qDeleteAll(m_reviews);
-}
+ReviewsModel::~ReviewsModel() = default;
 
 QHash< int, QByteArray > ReviewsModel::roleNames() const
 {
@@ -101,7 +97,6 @@ void ReviewsModel::setResource(AbstractResource* app)
 {
     if(m_app!=app) {
         beginResetModel();
-        qDeleteAll(m_reviews);
         m_reviews.clear();
         m_lastPage = 0;
         endResetModel();
@@ -134,7 +129,7 @@ void ReviewsModel::restartFetching()
 
 void ReviewsModel::fetchMore(const QModelIndex& parent)
 {
-    if(!m_backend || !m_app || m_app->backend()->isFetching() || m_backend->isFetching() || parent.isValid() || !m_canFetchMore)
+    if(!m_backend || !m_app || parent.isValid() || !m_canFetchMore)
         return;
 
     m_lastPage++;
@@ -142,7 +137,7 @@ void ReviewsModel::fetchMore(const QModelIndex& parent)
 //     qDebug() << "fetching reviews... " << m_lastPage;
 }
 
-void ReviewsModel::addReviews(AbstractResource* app, const QList<Review*>& reviews)
+void ReviewsModel::addReviews(AbstractResource* app, const QVector<ReviewPtr>& reviews)
 {
     if(app!=m_app)
         return;
@@ -165,7 +160,7 @@ bool ReviewsModel::canFetchMore(const QModelIndex& /*parent*/) const
 
 void ReviewsModel::markUseful(int row, bool useful)
 {
-    Review* r = m_reviews[row];
+    Review* r = m_reviews[row].data();
     r->setUsefulChoice(useful ? Yes : No);
 //     qDebug() << "submitting usefulness" << r->applicationName() << r->id() << useful;
     m_backend->submitUsefulness(r, useful);
@@ -175,12 +170,12 @@ void ReviewsModel::markUseful(int row, bool useful)
 
 void ReviewsModel::deleteReview(int row)
 {
-    Review* r = m_reviews[row];
+    Review* r = m_reviews[row].data();
     m_backend->deleteReview(r);
 }
 
 void ReviewsModel::flagReview(int row, const QString& reason, const QString& text)
 {
-    Review* r = m_reviews[row];
+    Review* r = m_reviews[row].data();
     m_backend->flagReview(r, reason, text);
 }
