@@ -76,8 +76,7 @@ void UpdateModel::setBackend(ResourcesUpdatesModel* updates)
 void UpdateModel::resourceHasProgressed(AbstractResource* res, qreal progress)
 {
     UpdateItem* item = itemFromResource(res);
-    if (!item)
-        return;
+    Q_ASSERT(item);
     item->setProgress(progress);
 
     const QModelIndex idx = indexFromItem(item);
@@ -86,12 +85,10 @@ void UpdateModel::resourceHasProgressed(AbstractResource* res, qreal progress)
 
 void UpdateModel::activityChanged()
 {
-    if(ResourcesModel::global()->isFetching()) {
-        setResources(QList<AbstractResource*>());
-    } else if(m_updates && !m_updates->isProgressing()) {
-        m_updates->prepare();
-        setResources(m_updates->toUpdate());
-    }
+    if (m_updates->isProgressing())
+        return;
+    m_updates->prepare();
+    setResources(m_updates->toUpdate());
 }
 
 QVariant UpdateModel::data(const QModelIndex &index, int role) const
