@@ -149,10 +149,8 @@ void DummyTest::testFetch()
 
     //fetches updates, adds new things
     m_appBackend->messageActions().at(0)->trigger();
-    QCOMPARE(m_model->isFetching(), true);
     QSignalSpy spy(m_model, SIGNAL(allInitialized()));
     QVERIFY(spy.wait(80000));
-    QCOMPARE(m_model->isFetching(), false);
     auto resources2 = fetchResources(m_appBackend->search({}));
     QCOMPARE(m_appBackend->property("startElements").toInt()*4, resources2.count());
 }
