@@ -296,7 +296,7 @@ ResultsStream* KNSBackend::search(const AbstractResourcesBackend::Filters& filte
                 ret += r;
         }
         return new ResultsStream(QStringLiteral("KNS-installed"), ret);
-    } else if (filter.category && filter.category->matchesCategoryName(m_categories.first())) {
+    } else if (filter.category && filter.category->matchesCategoryName(m_categories.constFirst())) {
         return searchStream(filter.search);
     } else if (!filter.search.isEmpty()) {
         return searchStream(filter.search);
