@@ -73,7 +73,9 @@ QVector<AbstractResource*> KNSBackendTest::getResources(ResultsStream* stream)
 QVector<AbstractResource*> KNSBackendTest::getAllResources(AbstractResourcesBackend* backend)
 {
     AbstractResourcesBackend::Filters f;
-    f.category = CategoryModel::global()->rootCategories().first();
+    if (CategoryModel::global()->rootCategories().isEmpty())
+        CategoryModel::global()->populateCategories();
+    f.category = CategoryModel::global()->rootCategories().constFirst();
     return getResources(backend->search(f));
 }
 
@@ -125,7 +127,7 @@ void KNSBackendTest::testReviews()
     QVERIFY(spy.count() || spy.wait());
 }
 
-void KNSBackendTest::reviewsArrived(AbstractResource* r, const QList< Review* >& revs)
+void KNSBackendTest::reviewsArrived(AbstractResource* r, const QVector<ReviewPtr>& revs)
 {
     m_r = r;
     m_revs = revs;
