@@ -28,13 +28,13 @@ class AppPackageKitResource : public PackageKitResource
 {
     Q_OBJECT
     public:
-        explicit AppPackageKitResource(const Appstream::Component& data, PackageKitBackend* parent);
+        explicit AppPackageKitResource(const AppStream::Component& data, const QString &packageName, PackageKitBackend* parent);
 
         QString appstreamId() const override;
 
         bool isTechnical() const override;
         QString name() override;
-        QString icon() const override;
+        QVariant icon() const override;
         QStringList mimetypes() const override;
         QStringList categories() override;
         QString longDescription() override;
@@ -50,11 +50,12 @@ class AppPackageKitResource : public PackageKitResource
         QList<PackageState> addonsInformation() override;
         QStringList extends() const override;
         void fetchScreenshots() override;
+        void fetchChangelog() override;
 
     private:
-        QStringList findProvides(Appstream::Provides::Kind kind) const;
+        QStringList findProvides(AppStream::Provided::Kind kind) const;
 
-        const Appstream::Component m_appdata;
+        const AppStream::Component m_appdata;
 };
 
 #endif // APPPACKAGEKITRESOURCE_H
