@@ -29,18 +29,7 @@
 #include <QTimer>
 #include <QSet>
 #include <PackageKit/Transaction>
-
-#ifdef NEWAPPSTREAM
 #include <AppStreamQt/pool.h>
-#include <AppStreamQt/provided.h>
-namespace AppStream {
-    typedef Provided Provides;
-    typedef Pool Database;
-}
-namespace Appstream = AppStream;
-#else
-#include <AppstreamQt/database.h>
-#endif
 
 class AppstreamReviews;
 class AppPackageKitResource;
@@ -56,10 +45,10 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         
         AbstractBackendUpdater* backendUpdater() const override;
         AbstractReviewsBackend* reviewsBackend() const override;
-        
-        QVector< AbstractResource* > allResources() const override;
-        AbstractResource* resourceByPackageName(const QString& name) const override;
-        QList<AbstractResource*> searchPackageName(const QString& searchText) override;
+        QSet<AbstractResource*> resourcesByPackageName(const QString& name) const;
+
+        ResultsStream* search(const AbstractResourcesBackend::Filters & search) override;
+        ResultsStream* findResourceByPackageName(const QUrl& search) override;
         int updatesCount() const override;
         
         void installApplication(AbstractResource* app) override;
@@ -79,9 +68,9 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         void resolvePackages(const QStringList &packageNames);
         void fetchDetails(const QString& pkgid);
 
+        AbstractResource * resourceForFile(const QUrl & ) override;
+
     public Q_SLOTS:
-        void transactionCanceled(Transaction* t);
-        void removeTransaction(Transaction* t);
         void reloadPackageList();
         void refreshDatabase();
 
@@ -97,19 +86,17 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         void getUpdatesDetailsFinished(PackageKit::Transaction::Exit,uint);
 
     private:
-        QSet<AbstractResource*> resourcesByPackageName(const QString& name) const;
         template <typename T>
         T resourcesByPackageNames(const QStringList& names) const;
 
-        void addTransaction(PKTransaction* trans);
         void checkDaemonRunning();
         void acquireFetching(bool f);
         void includePackagesToAdd();
         void performDetailsFetch();
+        AppPackageKitResource* addComponent(const AppStream::Component& component, const QStringList& pkgNames);
         QAction* createActionForService(const QString &filename);
 
-        Appstream::Database m_appdata;
-        QList<Transaction*> m_transactions;
+        AppStream::Pool m_appdata;
         PackageKitUpdater* m_updater;
         QPointer<PackageKit::Transaction> m_refresher;
         int m_isFetching;
