@@ -21,6 +21,7 @@
 #define PACKAGEKITNOTIFIER_H
 
 #include <BackendNotifierModule.h>
+#include <QPointer>
 #include <QVariantList>
 #include <PackageKit/Transaction>
 
@@ -41,10 +42,11 @@ public:
     explicit PackageKitNotifier(QObject* parent = nullptr);
     ~PackageKitNotifier() override;
 
-    bool isSystemUpToDate() const final;
-    uint securityUpdatesCount() final;
-    uint updatesCount() final;
-    void recheckSystemUpdateNeeded() final;
+    bool isSystemUpToDate() const override;
+    uint securityUpdatesCount() override;
+    uint updatesCount() override;
+    void recheckSystemUpdateNeeded() override;
+    void refreshDatabase();
 
 private Q_SLOTS:
     void package(PackageKit::Transaction::Info info, const QString &packageID, const QString &summary);
@@ -54,6 +56,7 @@ private:
     Update m_update;
     uint m_securityUpdates;
     uint m_normalUpdates;
+    QPointer<PackageKit::Transaction> m_refresher;
 };
 
 #endif
